address property
EthereumAddress
address
final
The Ethereum address at which this contract is reachable.
Implementation
final EthereumAddress address;
The Ethereum address at which this contract is reachable.
final EthereumAddress address;