from property
EthereumAddress?
from
final
The address of the sender of this transaction.
This can be set to null, in which case the client will use the address belonging to the credentials used to this transaction.
Implementation
final EthereumAddress? from;