to property
EthereumAddress?
to
final
The recipient of this transaction, or null for transactions that create a contract.
Implementation
final EthereumAddress? to;
The recipient of this transaction, or null for transactions that create a contract.
final EthereumAddress? to;