gasPrice property
EtherAmount
gasPrice
final
The amount of Ether that was used to pay for one unit of gas.
Implementation
final EtherAmount gasPrice;
The amount of Ether that was used to pay for one unit of gas.
final EtherAmount gasPrice;