TransactionReceipt class

Constructors

TransactionReceipt({required Uint8List transactionHash, required int transactionIndex, required Uint8List blockHash, required BigInt cumulativeGasUsed, BlockNum blockNumber = const BlockNum.pending(), EthereumAddress? contractAddress, bool? status, EthereumAddress? from, EthereumAddress? to, BigInt? gasUsed, EtherAmount? effectiveGasPrice, List<FilterEvent> logs = const []})
TransactionReceipt.fromMap(Map<String, dynamic> map)

Properties

blockHash Uint8List
Hash of the block where this transaction is in (32 bytes).
final
blockNumber BlockNum
Block number where this transaction is in.
final
contractAddress → EthereumAddress?
The address of the contract created if the transaction was a contract creation. null otherwise.
final
cumulativeGasUsed BigInt
The total amount of gas used when this transaction was executed in the block.
final
effectiveGasPrice → EtherAmount?
final
from → EthereumAddress?
Address of the sender.
final
gasUsed BigInt?
The amount of gas used by this specific transaction alone.
final
hashCode int
The hash code for this object.
no setteroverride
logs List<FilterEvent>
Array of logs generated by this transaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
Whether this transaction was executed successfully.
final
to → EthereumAddress?
Address of the receiver or null if it was a contract creation transaction.
final
transactionHash Uint8List
Hash of the transaction (32 bytes).
final
transactionIndex int
Index of the transaction's position in the block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override