to property
EthereumAddress?
to
final
Address of the receiver or null if it was a contract creation
transaction.
Implementation
final EthereumAddress? to;
Address of the receiver or null if it was a contract creation
transaction.
final EthereumAddress? to;